/*
 * Define some 4.4BSD functions for Linux.
 *
 * All of these print your printf-style message.
 * The *err* ones exit the program with exit value eval afterwards.
 * The *x ones don't do a perror("") afterwards.  All the others do.
 */

#include <stdarg.h>
#include <stdio.h>
#include "err.h"

void err(int eval, const char *fmt, ...) {
	va_list ap;
	va_start(ap, fmt);
	verr(eval, fmt, ap);
	va_end(ap);
}
void errx(int eval, const char *fmt, ...) {
	va_list ap;
	va_start(ap, fmt);
	verrx(eval, fmt, ap);
	va_end(ap);
}
void warn(const char *fmt, ...) {
	va_list ap;
	va_start(ap, fmt);
	vwarn(fmt, ap);
	va_end(ap);
}
void warnx(const char *fmt, ...) {
	va_list ap;
	va_start(ap, fmt);
	vwarnx(fmt, ap);
	va_end(ap);
}

/* Now, all these functions are supposed to print the program's name,
 * not their own names, but the program's name is not available in a
 * portable fashion. */

void verr(int eval, const char *fmt, va_list args) {
	fprintf(stderr, "verr: ");
	if (fmt != NULL) {
		vfprintf(stderr, fmt, args);
	}
	perror("");
	exit(eval);
}
void verrx(int eval, const char *fmt, va_list args) {
	fprintf(stderr, "verrx: ");
	if (fmt != NULL) {
		vfprintf(stderr, fmt, args);
	}
	fprintf(stderr, "\n");
	exit(eval);
}
void vwarn(const char *fmt, va_list args) {
	fprintf(stderr, "vwarn: ");
	if (fmt != NULL) {
		vfprintf(stderr, fmt, args);
	}
	perror("");
}
void vwarnx(const char *fmt, va_list args) {
	fprintf(stderr, "vwarnx: ");
	if (fmt != NULL) {
		vfprintf(stderr, fmt, args);
	}
	fprintf(stderr, "\n");
}
